#
# spec file for package libkrun
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global rustflags '-Clink-arg=-Wl,-z,relro,-z,now'
Name:           libkrun
Version:        1.4.4
Release:        bp155.1.11
Summary:        A dynamic library providing KVM-based process isolation capabilities
License:        Apache-2.0
URL:            https://github.com/containers/libkrun
Source0:        libkrun-%{version}.tar.gz
Source1:        vendor.tar.xz
Source2:        cargo_config
# libkrunfw is a plugin for us, more than a full-fledged library,
# so let's avoid setting up a SONAME etc (which upstream is now doing).
Patch1:         not-set-soname-as-it-is-plugin.patch
ExclusiveArch:  x86_64 aarch64
BuildRequires:  cargo >= 1.43.0
BuildRequires:  gcc
BuildRequires:  glibc-static
BuildRequires:  libkrunfw >= 0.6
BuildRequires:  libopenssl-devel
BuildRequires:  rust
Requires:       libkrunfw >= 0.6
%ifarch aarch64
BuildRequires:  libfdt-devel >= 1.6.0
%endif
Conflicts:      libkrun-devel <= 0.1.7
Conflicts:      libkrun0 <= 0.1.7

%description
libkrun is a dynamic library that allows programs to easily acquire the ability to run processes in a partially isolated environment using KVM Virtualization.

It integrates a VMM (Virtual Machine Monitor, the userspace side of an Hypervisor) with the minimum amount of emulated devices required to its purpose, abstracting most of the complexity that comes from Virtual Machine management, offering users a simple C API.

%prep
%setup -qa1
%patch1 -p1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
export RUSTFLAGS=%{rustflags}
%ifarch x86_64
%make_build SEV=1
%endif
%make_build

%install
export RUSTFLAGS=%{rustflags}
%ifarch x86_64
%make_install SEV=1 PREFIX=%{_prefix}
%endif
%make_install PREFIX=%{_prefix}

%files
%license LICENSE
%doc README.md
%{_libdir}/libkrun.so
%ifarch x86_64
%{_libdir}/libkrun-sev.so
%endif
%{_includedir}/libkrun.h

%changelog
* Thu Sep 29 2022 Dario Faggioli <dfaggioli@suse.com>
- Build the SEV version first, so we don't overwrite the non-SEV
  enabled plugin with the SEV one.
* Wed Sep 28 2022 dfaggioli@suse.com
- Update to version 1.4.4:
  * Bump version to v1.4.4
  * fs/macos: drop value mutability in read/write
  * fs/macos: avoid deadlock in open_inode
  * fs/macos: Fix path replacing on rename dir
  * Bump version to v1.4.3
  * devices/fs: Drop mutability from FileReadWriteAtVolatile
  * fs/macos: keep track of unlinked files
  * devices: add missing fence in Queue
  * Replace mpsc with crossbeam-channel
  * Bump version to v1.4.2
  * init: override kernel's HOME and TERM envs
  * init: ensure "/dev" is properly mounted
  * init: set a default hostname if no env is present
  * Makefile: drop library dependency on install
  * sev: temporarily vendorize kbs-types
  * sev: replace ureq with curl
  * Bump version to v1.4.1
  * clippy: Derive Eq in addition of PartialEq
  * macos: fix symlink ownership and mode attrs
  * Makefile: force creation of symlinks on install
  * sev: inform the user about progress
  * sev: extend TEE config and override VmConfig
  * Bump version to v1.4.0
  * sev: write zero page and include in measurement
  * sev: adopt the tentative KBS attestation protocol
  * sev: update sev crate to 0.3
  * sev: drop reqwest dependency
  * sev: replace attestation_url with tee_config_file
  * Bump version to v1.3.0
  * init: be permissive with non-ASCII bytes
  * init: add support for Entrypoint
  * init: deal with missing "/dev"
  * init: don't override existing env vars
  * libkrun: add krun_set_env()
  * sev: don't rely on cmdline_secret size and unlink
  * libkrun: remove KRUN_INIT and KRUN_WORKDIR defaults
  * init: Add cmdline_secret and config file support
  * Bump version to v1.2.3
  * macos: use upstream buildah xattr key
  * macos: honor flag enabling/disabling xattr
  * README.md: add known users and contact sections
* Wed Aug  3 2022 Dario Faggioli <dfaggioli@suse.com>
- Reconcile spec file and package content (reference .xz and
  get rid of .zst)
* Fri Jul 29 2022 fcrozat@suse.com
- Update to version 1.2.2:
  * Bump version to v1.2.2
  * vsock: remove stray println
* Wed Jun 22 2022 dfaggioli@suse.com
- Run services and update vendored dependencies
- Update to version 1.2.1:
  * Bump vm-memory dependency from 0.7.0 to 0.8.0
- Update to version to 1.2.0:
  * Disable virtio-fs DAX
    + Fixes a bug triggered when using openSUSE images
  * vsock: defer TSI proxy removal
* Fri Jun 17 2022 dfaggioli@suse.com
- Update to version 1.1.0:
  * vsock: restore lost port mapping feature
  * vsock: translate errno to macOS to Linux
  * vsock: use MSG_NOSIGNAL to avoid SIGPIPE
  * vsock: update to nix 0.24.1
  * vsock: make accept() and explicit operation
- Update to version to v1.0.0
  * Update README.md
  * CI: run clippy tests with amd-sev feature too
  * Implement virtio-rng device
  * vmm: disable test_get_supported_cpuid
  * sev: use a different name when building with SEV
  * sev: switch to upstream kvm-bindings/ioctls
  * Makefile: add versioning to the output library
  * arch/aarch64: remove dependency on device_tree
  * libkrun: remove unneeded "cc" dependency
- Update to version to 0.2.0
  * Replace old vsock with TSIv2's vsock
  * macos: operate directly on kqueue in epoll
  * utils: Allow Epoll to be cloned
  * Replace "logger" crate with env_logger+log
- Patches added:
  * not-set-soname-as-it-is-plugin.patch
* Fri May 27 2022 dfaggioli@suse.com
- Automatic update of vendored dependencies
- Update to version 0.1.8.
- (From upstream) Bump version to 0.1.8. We're about to introduce
  some breaking changes that will lead us to 0.2.0, so let's
  release a version now so people can get the latest clean ups
  without jumping all the way into 0.2.
- Some changes:
  * utils: drop unused functionality
  * CI: fail on clippy warnings
  * cpuid/logger: remove  "fn main" in doctests
  * Use vm-memory from crates.io
  * Remove unneeded extern declarations
  * libkrun: fix clippy warnings
  * libkrun: set Rust Edition to 2021
  * vmm: fix clippy warnings
  * vmm: set Rust Edition to 2021
  * kernel: fix clippy warnings
  * kernel: set Rust Edition to 2021
  * logger: fix clippy warnings
  * logger: update code to Rust 2021
  * polly: fix clippy warnings
  * polly: set Rust Edition to 2021
  * utils: fix clippy warnings
  * utils: set Rust Edition to 2021
  * devices: fix clippy warnings
  * devices: set Rust Edition to 2021
  * cpuid: fix clippy warnings
  * cpuid: update code to Rust 2021
  * arch: fix clippy warnings
  * arch: update code to Rust 2021
  * SEV: Ensure space for BIOS is always reserved
  * SEV: Implement support for SEV-ES
  * SEV: Increase the RAM of the examples to 2 GiB
  * SEV: Add the SEV flag to the Makefiles
  * SEV: Add a couple of examples fro libkrun-SEV
  * SEV: Automatically detect AMD CPU model
  * SEV: Implement support for Remote Attestation
  * SEV: Teach init how to open a LUKS volume
  * SEV: Add support for initramfs
  * SEV: Import virtio-block support from Firecraker
  * SEV: Initial plain SEV support
  * SEV: Configure MTRR MSR
  * SEV: Load qboot into the reset vector
  * CI: use default Cargo features on tests
* Fri Aug  6 2021 Frederic Crozat <fcrozat@suse.com>
- Don't try follow library policy, libkrun is a plugin.
* Fri Mar 19 2021 Dario Faggioli <dfaggioli@suse.com>
- enable only the arch-es that we know are supported (x86_64 and Arm64)
- build fails with old versions of cargo. Set a minimum version
* Fri Mar 19 2021 Dario Faggioli <dfaggioli@suse.com>
- fixup the obscpio files for 0.1.7
* Fri Mar 19 2021 dfaggioli@suse.com
- Update to version 0.1.7:
  * libkrun: Bump version to 0.1.7
  * devices/fs: fix listxattr on macOS
  * libkrun: Bump version to 0.1.6
  * vmm: Add "no-kvmapf" to the kernel command line
  * libkrun: Bump version to 0.1.5
  * libkrun: Put env vars values between quotes
  * init: Fix format warning in printf()
  * init: Compile with -Wall
  * Makefile: Have init.c as a prerequisite of init
  * init: Fix the perror() messages
* Fri Mar 19 2021 Dario Faggioli <dfaggioli@suse.com>
- there's no libkrunfw for i586 so exclude it here as well
* Sat Feb 27 2021 Dario Faggioli <dfaggioli@suse.com>
- Set all services to disabled
* Thu Feb 18 2021 dmacvicar@suse.com
- Update to version v0.1.4:
  * libkrun: Put env vars values between quotes
  * init: Fix format warning in printf()
  * init: Compile with -Wall
  * Makefile: Have init.c as a prerequisite of init
  * init: Fix the perror() messages
  * examples: Introduce the "rootfs" make target
  * README: Mention the C Library static on requirements
  * libkrun: Fix type of arguments mapped_volumes and port_map
  * libkrun: Add support for setting RLIMITs in the guests
  * README.md: Add instructions for building under macOS
* Thu Feb 18 2021 Duncan Mac-Vicar <duncan@mac-vicar.eu>
- Initial package for 0.1.4
  Based on Fedora package from Sergio Lopez <slp@redhat.com>
